==> jc-1.4.0.tar.gz: java/security/cert/PKIXCertPathChecker.h <==
// public abstract class java.security.cert.PKIXCertPathChecker

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b976c651cf009c14 java_security_cert_PKIXCertPathChecker

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_PKIXCertPathChecker_H_
#define _JC_java_security_cert_PKIXCertPathChecker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_security_cert_Certificate$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_java_security_cert_PKIXCertPathChecker$sub_refs	_jc_java_security_cert_PKIXCertPathChecker$sub_refs;
typedef struct _jc_java_security_cert_PKIXCertPathChecker$sub_nonrefs	_jc_java_security_cert_PKIXCertPathChecker$sub_nonrefs;
typedef struct _jc_java_security_cert_PKIXCertPathChecker$refs	_jc_java_security_cert_PKIXCertPathChecker$refs;
typedef struct _jc_java_security_cert_PKIXCertPathChecker$nonrefs	_jc_java_security_cert_PKIXCertPathChecker$nonrefs;
typedef struct _jc_java_security_cert_PKIXCertPathChecker$object	_jc_java_security_cert_PKIXCertPathChecker$object;

typedef const struct _jc_java_security_cert_PKIXCertPathChecker$vmethods	_jc_java_security_cert_PKIXCertPathChecker$vmethods;
typedef const struct _jc_java_security_cert_PKIXCertPathChecker$vtable	_jc_java_security_cert_PKIXCertPathChecker$vtable;
typedef const struct _jc_java_security_cert_PKIXCertPathChecker$vtype	_jc_java_security_cert_PKIXCertPathChecker$vtype;

// Constructors
extern void _jc_java_security_cert_PKIXCertPathChecker$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_cert_PKIXCertPathChecker$object *);

// Virtual methods
extern void _jc_java_security_cert_PKIXCertPathChecker$method$check$10519c7db8d3bf5c(_jc_env *, struct _jc_java_security_cert_PKIXCertPathChecker$object *, struct _jc_java_security_cert_Certificate$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_java_security_cert_PKIXCertPathChecker$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_security_cert_PKIXCertPathChecker$object *);
extern struct _jc_object *_jc_java_security_cert_PKIXCertPathChecker$method$getSupportedExtensions$fb61bd11e9a8992a(_jc_env *, struct _jc_java_security_cert_PKIXCertPathChecker$object *);
extern void _jc_java_security_cert_PKIXCertPathChecker$method$init$3cb19efd060b868c(_jc_env *, struct _jc_java_security_cert_PKIXCertPathChecker$object *, jboolean);
extern jboolean _jc_java_security_cert_PKIXCertPathChecker$method$isForwardCheckingSupported$023d394939de6e51(_jc_env *, struct _jc_java_security_cert_PKIXCertPathChecker$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_PKIXCertPathChecker$method_info$check$10519c7db8d3bf5c;
extern _jc_method _jc_java_security_cert_PKIXCertPathChecker$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_security_cert_PKIXCertPathChecker$method_info$getSupportedExtensions$fb61bd11e9a8992a;
extern _jc_method _jc_java_security_cert_PKIXCertPathChecker$method_info$init$3cb19efd060b868c;
extern _jc_method _jc_java_security_cert_PKIXCertPathChecker$method_info$isForwardCheckingSupported$023d394939de6e51;

// Virtual methods structure
struct _jc_java_security_cert_PKIXCertPathChecker$vmethods {
	void	(*check$10519c7db8d3bf5c)(_jc_env *, struct _jc_java_security_cert_PKIXCertPathChecker$object *, struct _jc_java_security_cert_Certificate$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_security_cert_PKIXCertPathChecker$object *);
	struct _jc_object	*(*getSupportedExtensions$fb61bd11e9a8992a)(_jc_env *, struct _jc_java_security_cert_PKIXCertPathChecker$object *);
	void	(*init$3cb19efd060b868c)(_jc_env *, struct _jc_java_security_cert_PKIXCertPathChecker$object *, jboolean);
	jboolean	(*isForwardCheckingSupported$023d394939de6e51)(_jc_env *, struct _jc_java_security_cert_PKIXCertPathChecker$object *);
};

// Vtable
struct _jc_java_security_cert_PKIXCertPathChecker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_PKIXCertPathChecker$vmethods	java_security_cert_PKIXCertPathChecker;
};

// Vtype
struct _jc_java_security_cert_PKIXCertPathChecker$vtype {
	_jc_type			type;
	_jc_java_security_cert_PKIXCertPathChecker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_PKIXCertPathChecker$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_cert_PKIXCertPathChecker$refs {
    _jc_java_security_cert_PKIXCertPathChecker$sub_refs	java_security_cert_PKIXCertPathChecker;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_PKIXCertPathChecker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_PKIXCertPathChecker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_PKIXCertPathChecker$sub_nonrefs	java_security_cert_PKIXCertPathChecker;
};

// Object instance structure
struct _jc_java_security_cert_PKIXCertPathChecker$object {
	_jc_java_security_cert_PKIXCertPathChecker$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_PKIXCertPathChecker$vtype	*vtype;
	_jc_java_security_cert_PKIXCertPathChecker$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_PKIXCertPathChecker$vtype _jc_java_security_cert_PKIXCertPathChecker$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_PKIXCertPathChecker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_PKIXCertPathChecker$class_object;

#endif	/* _JC_java_security_cert_PKIXCertPathChecker_H_ */

==> jc-1.4.6.tar.gz: java/security/cert/PKIXCertPathChecker.h <==
// public abstract class java.security.cert.PKIXCertPathChecker

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b976c651cf009c14 java_security_cert_PKIXCertPathChecker

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_PKIXCertPathChecker_H_
#define _JC_java_security_cert_PKIXCertPathChecker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_security_cert_Certificate$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_java_security_cert_PKIXCertPathChecker$sub_refs	_jc_java_security_cert_PKIXCertPathChecker$sub_refs;
typedef struct _jc_java_security_cert_PKIXCertPathChecker$sub_nonrefs	_jc_java_security_cert_PKIXCertPathChecker$sub_nonrefs;
typedef struct _jc_java_security_cert_PKIXCertPathChecker$refs	_jc_java_security_cert_PKIXCertPathChecker$refs;
typedef struct _jc_java_security_cert_PKIXCertPathChecker$nonrefs	_jc_java_security_cert_PKIXCertPathChecker$nonrefs;
typedef struct _jc_java_security_cert_PKIXCertPathChecker$object	_jc_java_security_cert_PKIXCertPathChecker$object;

typedef const struct _jc_java_security_cert_PKIXCertPathChecker$vmethods	_jc_java_security_cert_PKIXCertPathChecker$vmethods;
typedef const struct _jc_java_security_cert_PKIXCertPathChecker$vtable	_jc_java_security_cert_PKIXCertPathChecker$vtable;
typedef const struct _jc_java_security_cert_PKIXCertPathChecker$vtype	_jc_java_security_cert_PKIXCertPathChecker$vtype;

// Constructors
extern void _jc_java_security_cert_PKIXCertPathChecker$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_cert_PKIXCertPathChecker$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_security_cert_PKIXCertPathChecker$method$check$10519c7db8d3bf5c(_jc_env *, struct _jc_java_security_cert_PKIXCertPathChecker$object *, struct _jc_java_security_cert_Certificate$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_security_cert_PKIXCertPathChecker$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_security_cert_PKIXCertPathChecker$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_security_cert_PKIXCertPathChecker$method$getSupportedExtensions$fb61bd11e9a8992a(_jc_env *, struct _jc_java_security_cert_PKIXCertPathChecker$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_cert_PKIXCertPathChecker$method$init$3cb19efd060b868c(_jc_env *, struct _jc_java_security_cert_PKIXCertPathChecker$object *, jboolean) _JC_JCNI_ATTR;
extern jboolean _jc_java_security_cert_PKIXCertPathChecker$method$isForwardCheckingSupported$023d394939de6e51(_jc_env *, struct _jc_java_security_cert_PKIXCertPathChecker$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_PKIXCertPathChecker$method_info$check$10519c7db8d3bf5c;
extern _jc_method _jc_java_security_cert_PKIXCertPathChecker$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_security_cert_PKIXCertPathChecker$method_info$getSupportedExtensions$fb61bd11e9a8992a;
extern _jc_method _jc_java_security_cert_PKIXCertPathChecker$method_info$init$3cb19efd060b868c;
extern _jc_method _jc_java_security_cert_PKIXCertPathChecker$method_info$isForwardCheckingSupported$023d394939de6e51;

// Virtual methods structure
struct _jc_java_security_cert_PKIXCertPathChecker$vmethods {
	void	(*check$10519c7db8d3bf5c)(_jc_env *, struct _jc_java_security_cert_PKIXCertPathChecker$object *, struct _jc_java_security_cert_Certificate$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_security_cert_PKIXCertPathChecker$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getSupportedExtensions$fb61bd11e9a8992a)(_jc_env *, struct _jc_java_security_cert_PKIXCertPathChecker$object *) _JC_JCNI_ATTR;
	void	(*init$3cb19efd060b868c)(_jc_env *, struct _jc_java_security_cert_PKIXCertPathChecker$object *, jboolean) _JC_JCNI_ATTR;
	jboolean	(*isForwardCheckingSupported$023d394939de6e51)(_jc_env *, struct _jc_java_security_cert_PKIXCertPathChecker$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_cert_PKIXCertPathChecker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_PKIXCertPathChecker$vmethods	java_security_cert_PKIXCertPathChecker;
};

// Vtype
struct _jc_java_security_cert_PKIXCertPathChecker$vtype {
	_jc_type			type;
	_jc_java_security_cert_PKIXCertPathChecker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_PKIXCertPathChecker$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_cert_PKIXCertPathChecker$refs {
    _jc_java_security_cert_PKIXCertPathChecker$sub_refs	java_security_cert_PKIXCertPathChecker;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_PKIXCertPathChecker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_PKIXCertPathChecker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_PKIXCertPathChecker$sub_nonrefs	java_security_cert_PKIXCertPathChecker;
};

// Object instance structure
struct _jc_java_security_cert_PKIXCertPathChecker$object {
	_jc_java_security_cert_PKIXCertPathChecker$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_PKIXCertPathChecker$vtype	*vtype;
	_jc_java_security_cert_PKIXCertPathChecker$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_PKIXCertPathChecker$vtype _jc_java_security_cert_PKIXCertPathChecker$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_PKIXCertPathChecker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_PKIXCertPathChecker$class_object;

#endif	/* _JC_java_security_cert_PKIXCertPathChecker_H_ */
